==> mgb-0.5.4.3-de.zip: mgb-0.5.4.3-de/eintragen_form.php <==
<?php
	/*
	MGB 0.5.4.3
	Copyright (C) 2004 - 2006  Juergen Grueneisl

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	*/

         $ausgabe.="<form action='".$PHP_SELF."' method='post' id='neuereintrag'>\n";
	$ausgabe.="<table summary='eintragen' class='rahmen_eintragen' style='width:90%;border:none' cellspacing='0' cellpadding='0'>\n";
	$ausgabe.="<tr>\n";
	$ausgabe.="<td class='rahmen_eintragen'>\n";
	$ausgabe.="<input type='hidden' name='sent' value='1'>\n";
	$ausgabe.="<center>\n";
	$ausgabe.="<table summary='eintragen' class='eintragen' style='width:300px;border:none;'>\n";
	$ausgabe.="<tr>\n";
	$ausgabe.="<td class='eintragen' style='width:75px' align='right'>\n";
	$ausgabe.="<font>".$lang['name']."</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='eintragen' style='width:200px' align='center'>\n";
	$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='name' size='30' value='".$_POST[name]."'>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='sonst' style='width:25px' align='right'>\n";
	$ausgabe.="<font>*</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="</tr>\n";
	$ausgabe.="<tr>\n";
	$ausgabe.="<td class='eintragen' style='width:75px' align='right'>\n";
	$ausgabe.="<font>".$lang['city']."</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='eintragen' style='width:200px' align='center'>\n";
	$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='place' size='30' value='".$_POST[place]."'>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='sonst' style='width:25px' align='right'>\n";
	$ausgabe.="<font>&nbsp;</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="</tr>\n";
	$ausgabe.="<tr>\n";
	$ausgabe.="<td class='eintragen' style='width:75px' align='right'>\n";
	$ausgabe.="<font>".$lang['eMail']."</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='eintragen' style='width:200px' align='center'>\n";
	$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='email' size='30' value='".$_POST[email]."'>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='sonst' style='width:25px' align='right'>\n";
	$ausgabe.="<font>*</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="</tr>\n";
	$ausgabe.="<tr>\n";
	$ausgabe.="<td class='eintragen' style='width:75px' align='right'>\n";
	$ausgabe.="<font>".$lang['icq']."</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='eintragen' style='width:200px' align='center'>\n";
	$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='icq' size='30' value='".$_POST[icq]."'>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='sonst' style='width:25px' align='right'>\n";
	$ausgabe.="<font>&nbsp;</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="</tr>\n";
         $ausgabe.="<tr>\n";
	$ausgabe.="<td class='eintragen' style='width:75px' align='right'>\n";
	$ausgabe.="<font>".$lang['aim']."</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='eintragen' style='width:200px' align='center'>\n";
	$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='aim' size='30' value='".$_POST[aim]."'>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='sonst' style='width:25px' align='right'>\n";
	$ausgabe.="<font>&nbsp;</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="</tr>\n";
         $ausgabe.="<tr>\n";
	$ausgabe.="<td class='eintragen' style='width:75px' align='right'>\n";
	$ausgabe.="<font>".$lang['msn']."</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='eintragen' style='width:200px' align='center'>\n";
	$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='msn' size='30' value='".$_POST[msn]."'>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='sonst' style='width:25px' align='right'>\n";
	$ausgabe.="<font>&nbsp;</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="</tr>\n";
         $ausgabe.="<tr>\n";
	$ausgabe.="<td class='eintragen' style='width:75px' align='right'>\n";
	$ausgabe.="<font>".$lang['homepage']."</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='eintragen' style='width:200px' align='center'>\n";
	$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='hp' size='30' value='";
         if(!$_POST[hp])
         	{
                 $homepage="http://";
                 }
         else
         	{
                 $homepage=$_POST[hp];
                 }
	$ausgabe.=$homepage."'>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='sonst' style='width:25px' align='right'>\n";
	$ausgabe.="<font>&nbsp;</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="</tr>\n";
	$ausgabe.="<tr>\n";
	$ausgabe.="<td class='eintragen' style='width:75px' align='right'>\n";
	$ausgabe.="<font>".$lang['message']."</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='eintragen' style='width:200px' align='center'>\n";
	$ausgabe.="<textarea style='".$settings['inputtextstyle']."' name='message' rows='5' cols='23'>".$_POST[message]."</textarea>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='sonst' style='width:25px' align='right'>\n";
	$ausgabe.="<font>*</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="</tr>\n";
	$ausgabe.="</table>\n";
         $ausgabe.=$asmilie;
	if($settings['bbcodes'] == 1)
                	{
                 $ausgabe.="<table summary='bbcodes' class='eintragen' style='border:none;'>\n";
                 $ausgabe.="<tr>\n";
                 $ausgabe.="<td class='eintragen' align='left'>\n";
                 $ausgabe.="<center><div style='padding-bottom:5px;'><font>".$lang['bbcodes']."</font></div>\n";
                 $ausgabe.="<div style='padding-bottom:2px'><font>[b]<b>Text</b>[/b]</font></div>\n";
                 $ausgabe.="<div style='padding-bottom:2px'><font>[i]<i>Text</i>[/i]</font></div>\n";
         	$ausgabe.="<div style='padding-bottom:2px'><font>[url]http://www.test.de/[/url]</font></div>\n";
                 $ausgabe.="<div style='padding-bottom:2px'><font>[url=http://www.test.de/]test.de[/url]</font></div>\n";
                 $ausgabe.="<div style='padding-bottom:2px'><font>[size=12]<span style='font-size:12px'>Text</span>[/size]</font></div>\n";
                 $ausgabe.="<div style='padding-bottom:2px'><font>[color=FF9F00]<span style='color:#FF9F00'>Text</span>[/color]</font></div>\n";
                 $ausgabe.="</center>\n";
                 $ausgabe.="</td>\n";
                 $ausgabe.="</tr>\n";
                 $ausgabe.="</table>\n";
                 }
         if($settings['sendemailuserfrei'] == 1)
         	{
		$ausgabe.="<table summary='informieren' class='eintragen' style='width:400px;border:none;'>\n";
		$ausgabe.="<tr>\n";
		$ausgabe.="<td class='eintragen' style='width:370px' align='justify'>\n";
		$ausgabe.="<font>".$lang['notify']."</font>\n";
		$ausgabe.="</td>\n";
		$ausgabe.="<td class='eintragen' style='width:30px' align='right'>\n";
         	$ausgabe.="<input type='checkbox' name='notify' value='1' checked='checked'>\n";
         	$ausgabe.="</td>\n";
		$ausgabe.="</tr>\n";
         	$ausgabe.="</table>\n";
                 }
	$ausgabe.="<br>\n";
         $ausgabe.="<font>[".$lang['mandatory']."]</font><br><br>\n";
         $ausgabe.="<font>".$lang['quakecodes_before_link']."<a href='onlinehilfe/quake.html' target='_blank'>".$lang['quakecodes_link']."</a>".$lang['quakecodes_after_link']."</font><br><br>\n";
	$ausgabe.="<table summary='eintragen' class='eintragen' style='width:300px;border:none;'>\n";
         $ausgabe.="<tr>\n";
         $ausgabe.="<td class='eintragen' style='width:300px' align='center'>\n";
	$ausgabe.="<font>".$lang['captcha']."</font>\n";
	$ausgabe.="</td>\n";
         $ausgabe.="<tr>\n";
         $ausgabe.="<td class='eintragen' style='width:300px' align='center'>\n";
	$ausgabe.="<img src='captcha.php' width='120' height='40' title='".$lang['captcha']."' alt='".$lang['captcha']."'>";
	$ausgabe.="</td>\n";
	$ausgabe.="</tr>\n";
	$ausgabe.="<tr>\n";
         $ausgabe.="<td class='eintragen' style='width:300px' align='center'>\n";
	$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='captcha' size='6' value=''>\n";
	$ausgabe.="</td>\n";
         $ausgabe.="</tr>\n";
	$ausgabe.="</table>\n";
	$ausgabe.="<br>\n";
	$ausgabe.="<input type='submit' value='".$lang['send']."' style='".$settings['inputtextstyle']."'>\n";
         $ausgabe.="</center>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="</tr>\n";
	$ausgabe.="</table>\n";
	$ausgabe.="</form>\n";
?>

==> mgb-0.5.4.5-de.zip: mgb-0.5.4.5-de/eintragen_form.php <==
<?php
	/*
	MGB 0.5.4.5
	Copyright (C) 2004 - 2006  Juergen Grueneisl

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	*/

         $ausgabe.="<form action='".$PHP_SELF."' method='post' id='neuereintrag'>\n";
	$ausgabe.="<table summary='eintragen' class='rahmen_eintragen' style='width:90%;border:none' cellspacing='0' cellpadding='0'>\n";
	$ausgabe.="<tr>\n";
	$ausgabe.="<td class='rahmen_eintragen'>\n";
	$ausgabe.="<input type='hidden' name='sent' value='1'>\n";
	$ausgabe.="<center>\n";
	$ausgabe.="<table summary='eintragen' class='eintragen' style='width:300px;border:none;'>\n";
	$ausgabe.="<tr>\n";
	$ausgabe.="<td class='eintragen' style='width:75px' align='right'>\n";
	$ausgabe.="<font>".$lang['name']."</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='eintragen' style='width:200px' align='center'>\n";
	$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='name' size='30' value='".$_POST[name]."'>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='sonst' style='width:25px' align='right'>\n";
	$ausgabe.="<font>*</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="</tr>\n";
	$ausgabe.="<tr>\n";
	$ausgabe.="<td class='eintragen' style='width:75px' align='right'>\n";
	$ausgabe.="<font>".$lang['city']."</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='eintragen' style='width:200px' align='center'>\n";
	$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='place' size='30' value='".$_POST[place]."'>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='sonst' style='width:25px' align='right'>\n";
	$ausgabe.="<font>&nbsp;</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="</tr>\n";
	$ausgabe.="<tr>\n";
	$ausgabe.="<td class='eintragen' style='width:75px' align='right'>\n";
	$ausgabe.="<font>".$lang['eMail']."</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='eintragen' style='width:200px' align='center'>\n";
	$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='email' size='30' value='".$_POST[email]."'>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='sonst' style='width:25px' align='right'>\n";
	$ausgabe.="<font>*</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="</tr>\n";
	$ausgabe.="<tr>\n";
	$ausgabe.="<td class='eintragen' style='width:75px' align='right'>\n";
	$ausgabe.="<font>".$lang['icq']."</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='eintragen' style='width:200px' align='center'>\n";
	$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='icq' size='30' value='".$_POST[icq]."'>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='sonst' style='width:25px' align='right'>\n";
	$ausgabe.="<font>&nbsp;</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="</tr>\n";
         $ausgabe.="<tr>\n";
	$ausgabe.="<td class='eintragen' style='width:75px' align='right'>\n";
	$ausgabe.="<font>".$lang['aim']."</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='eintragen' style='width:200px' align='center'>\n";
	$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='aim' size='30' value='".$_POST[aim]."'>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='sonst' style='width:25px' align='right'>\n";
	$ausgabe.="<font>&nbsp;</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="</tr>\n";
         $ausgabe.="<tr>\n";
	$ausgabe.="<td class='eintragen' style='width:75px' align='right'>\n";
	$ausgabe.="<font>".$lang['msn']."</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='eintragen' style='width:200px' align='center'>\n";
	$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='msn' size='30' value='".$_POST[msn]."'>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='sonst' style='width:25px' align='right'>\n";
	$ausgabe.="<font>&nbsp;</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="</tr>\n";
         $ausgabe.="<tr>\n";
	$ausgabe.="<td class='eintragen' style='width:75px' align='right'>\n";
	$ausgabe.="<font>".$lang['homepage']."</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='eintragen' style='width:200px' align='center'>\n";
	$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='hp' size='30' value='";
         if(!$_POST[hp])
         	{
                 $homepage="http://";
                 }
         else
         	{
                 $homepage=$_POST[hp];
                 }
	$ausgabe.=$homepage."'>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='sonst' style='width:25px' align='right'>\n";
	$ausgabe.="<font>&nbsp;</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="</tr>\n";
	$ausgabe.="<tr>\n";
	$ausgabe.="<td class='eintragen' style='width:75px' align='right'>\n";
	$ausgabe.="<font>".$lang['message']."</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='eintragen' style='width:200px' align='center'>\n";
	$ausgabe.="<textarea style='".$settings['inputtextstyle']."' name='message' rows='5' cols='23'>".$_POST[message]."</textarea>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="<td class='sonst' style='width:25px' align='right'>\n";
	$ausgabe.="<font>*</font>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="</tr>\n";
	$ausgabe.="</table>\n";
         $ausgabe.=$asmilie;
	if($settings['bbcodes'] == 1)
                	{
                 $ausgabe.="<table summary='bbcodes' class='eintragen' style='border:none;'>\n";
                 $ausgabe.="<tr>\n";
                 $ausgabe.="<td class='eintragen' align='left'>\n";
                 $ausgabe.="<center><div style='padding-bottom:5px;'><font>".$lang['bbcodes']."</font></div>\n";
                 $ausgabe.="<div style='padding-bottom:2px'><font>[b]<b>Text</b>[/b]</font></div>\n";
                 $ausgabe.="<div style='padding-bottom:2px'><font>[i]<i>Text</i>[/i]</font></div>\n";
         	$ausgabe.="<div style='padding-bottom:2px'><font>[url]http://www.test.de/[/url]</font></div>\n";
                 $ausgabe.="<div style='padding-bottom:2px'><font>[url=http://www.test.de/]test.de[/url]</font></div>\n";
                 $ausgabe.="<div style='padding-bottom:2px'><font>[size=12]<span style='font-size:12px'>Text</span>[/size]</font></div>\n";
                 $ausgabe.="<div style='padding-bottom:2px'><font>[color=FF9F00]<span style='color:#FF9F00'>Text</span>[/color]</font></div>\n";
                 $ausgabe.="</center>\n";
                 $ausgabe.="</td>\n";
                 $ausgabe.="</tr>\n";
                 $ausgabe.="</table>\n";
                 }
         if($settings['sendemailuserfrei'] == 1)
         	{
		$ausgabe.="<table summary='informieren' class='eintragen' style='width:400px;border:none;'>\n";
		$ausgabe.="<tr>\n";
		$ausgabe.="<td class='eintragen' style='width:370px' align='justify'>\n";
		$ausgabe.="<font>".$lang['notify']."</font>\n";
		$ausgabe.="</td>\n";
		$ausgabe.="<td class='eintragen' style='width:30px' align='right'>\n";
         	$ausgabe.="<input type='checkbox' name='notify' value='1' checked='checked'>\n";
         	$ausgabe.="</td>\n";
		$ausgabe.="</tr>\n";
         	$ausgabe.="</table>\n";
                 }
	$ausgabe.="<br>\n";
         $ausgabe.="<font>[".$lang['mandatory']."]</font><br><br>\n";
         $ausgabe.="<font>".$lang['quakecodes_before_link']."<a href='onlinehilfe/quake.html' target='_blank'>".$lang['quakecodes_link']."</a>".$lang['quakecodes_after_link']."</font><br>\n";
	if($settings['captcha'] == 1)
		{
		$ausgabe.="<br>\n";
		$ausgabe.="<table summary='eintragen' class='eintragen' style='width:300px;border:none;'>\n";
         	$ausgabe.="<tr>\n";
         	$ausgabe.="<td class='eintragen' style='width:300px' align='center'>\n";
		$ausgabe.="<font>".$lang['captcha_text']."</font>\n";
		$ausgabe.="</td>\n";
         	$ausgabe.="<tr>\n";
         	$ausgabe.="<td class='eintragen' style='width:300px' align='center'>\n";
		$ausgabe.="<img src='captcha.php' width='120' height='40' title='".$lang['captcha']."' alt='".$lang['captcha']."'>";
		$ausgabe.="</td>\n";
		$ausgabe.="</tr>\n";
		$ausgabe.="<tr>\n";
         	$ausgabe.="<td class='eintragen' style='width:300px' align='center'>\n";
		$ausgabe.="<input type='text' style='".$settings['inputtextstyle']."' name='captcha' size='6' value=''>\n";
		$ausgabe.="</td>\n";
         	$ausgabe.="</tr>\n";
		$ausgabe.="</table>\n";
		}
	$ausgabe.="<br>\n";
	$ausgabe.="<input type='submit' value='".$lang['send']."' style='".$settings['inputtextstyle']."'>\n";
         $ausgabe.="</center>\n";
	$ausgabe.="</td>\n";
	$ausgabe.="</tr>\n";
	$ausgabe.="</table>\n";
	$ausgabe.="</form>\n";
?>
